==> mingw-w64-rclone-1.66.0-1.src.tar.zst: rclone-v1.66.0/docs/content/sponsor.md <==
---
title: "Sponsor"
description: "Sponsor the rclone project."
type: page
aliases:
- donate
---

# {{< icon "fa fa-heart heart" >}} Sponsor the rclone project

Rclone is a free open-source project with thousands of contributions
from volunteers all round the world and I would like to thank all of
you for donating your time to the project.

However, maintaining rclone is a lot of work - it is **my full time
job**. Nothing stands still in the world of cloud storage. Rclone
needs constant attention adapting to changes by cloud providers,
adding new providers, adding new features, keeping the integration
tests working, fixing bugs and many more things!

I love doing the work and I'd like to keep doing it - your support
helps make rclone possible.

Thank you :-)

{{< nick >}}

## Business users

If your business or your customers rely on rclone then it would make
sense to sponsor rclone to ensure that the open source project you
need stays healthy and well maintained.

Sponsorship can include support contracts, advertising deals and
consultancy.

Please see our business site [rclone.com](https://rclone.com) for
details.

{{< bizbutton >}}

## Personal users

If you are a personal user and you would like to support the project
with sponsorship as a way of saying thank you that would be most
appreciated. {{< icon "fa fa-heart heart" >}}

{{< monthly_donations >}}

If you don't want to contribute monthly then of course we'd love a one
off donation.

{{< one_off_donations >}}

## Our sponsors

Thank you very much to our sponsors:

{{< sponsor src="/img/logos/idrive_e2.svg" width="300" height="200" title="Visit our sponsor IDrive e2" link="https://www.idrive.com/e2/?refer=rclone">}}
{{< sponsor src="/img/logos/warp.svg" width="300" height="200" title="Visit our sponsor warp.dev" link="https://www.warp.dev/?utm_source=rclone&utm_medium=referral&utm_campaign=rclone_20231103">}}
{{< sponsor src="/img/logos/sia.svg" width="200" height="200" title="Visit our sponsor sia" link="https://sia.tech">}}

==> mingw-w64-rclone-1.67.0-1.src.tar.zst: rclone-v1.67.0/docs/content/sponsor.md <==
---
title: "Sponsor"
description: "Sponsor the rclone project."
type: page
aliases:
- donate
---

# {{< icon "fa fa-heart heart" >}} Sponsor the rclone project

Rclone is a free open-source project with thousands of contributions
from volunteers all round the world and I would like to thank all of
you for donating your time to the project.

However, maintaining rclone is a lot of work - it is **my full time
job**. Nothing stands still in the world of cloud storage. Rclone
needs constant attention adapting to changes by cloud providers,
adding new providers, adding new features, keeping the integration
tests working, fixing bugs and many more things!

I love doing the work and I'd like to keep doing it - your support
helps make rclone possible.

Thank you :-)

{{< nick >}}

## Business users

If your business or your customers rely on rclone then it would make
sense to sponsor rclone to ensure that the open source project you
need stays healthy and well maintained.

Sponsorship can include support contracts, advertising deals and
consultancy.

Please see our business site [rclone.com](https://rclone.com) for
details.

{{< bizbutton >}}

## Personal users

If you are a personal user and you would like to support the project
with sponsorship as a way of saying thank you that would be most
appreciated. {{< icon "fa fa-heart heart" >}}

{{< monthly_donations >}}

If you don't want to contribute monthly then of course we'd love a one
off donation.

{{< one_off_donations >}}

## Our sponsors

Thank you very much to our sponsors:

{{< sponsor src="/img/logos/backblaze.svg" width="300" height="200" title="Visit our sponsor Backblaze" link="https://www.backblaze.com/cloud-storage?utm_source=publisher&utm_medium=paid&utm_campaign=break-free-app-storage-q224-rclone">}}
{{< sponsor src="/img/logos/idrive_e2.svg" width="300" height="200" title="Visit our sponsor IDrive e2" link="https://www.idrive.com/e2/?refer=rclone">}}
{{< sponsor src="/img/logos/warp.svg" width="300" height="200" title="Visit our sponsor warp.dev" link="https://www.warp.dev/?utm_source=rclone&utm_medium=referral&utm_campaign=rclone_20231103">}}
{{< sponsor src="/img/logos/sia.svg" width="200" height="200" title="Visit our sponsor sia" link="https://sia.tech">}}
